import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.material.Button
import androidx.compose.material.MaterialTheme
import androidx.compose.material.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.interop.LocalUIViewController
import androidx.compose.ui.unit.dp
import androidx.compose.ui.window.ComposeUIViewController
import platform.UIKit.UINavigationController
import platform.UIKit.UISheetPresentationControllerDetent
import platform.UIKit.modalInPresentation
import platform.UIKit.sheetPresentationController

@Composable
fun App() {
  MaterialTheme {
    var showContent by remember { mutableStateOf(false) }
    Column(Modifier.fillMaxWidth(), horizontalAlignment = Alignment.CenterHorizontally) {
      Button(onClick = { showContent = !showContent }) {
        Text("Click me!")
      }
      if (showContent) {
        val rootVc = LocalUIViewController.current
        remember {
          val vc = ComposeUIViewController {
            LazyColumn {
              items(1000) {
                Text(
                  "hi ~ $it",
                  modifier = Modifier.padding(12.dp).fillMaxWidth()
                    .background(Color.Cyan.copy(alpha = 0.1f))
                )
              }
            }
          }
          val nav = UINavigationController(rootViewController = vc)
          // 始终保持展开，只能通过点击按钮关闭
          nav.modalInPresentation = true
          /// 配置 sheet 面板
          nav.sheetPresentationController?.also { sheet ->
            // 可以半屏、全屏
            sheet.setDetents(
              listOf(
                UISheetPresentationControllerDetent.mediumDetent(),
                UISheetPresentationControllerDetent.largeDetent(),
              )
            )
            sheet.preferredCornerRadius = 24.0
            // 当滚动到边缘时，滚动扩展
            sheet.prefersScrollingExpandsWhenScrolledToEdge = true
            // 显示可拖动的手柄
            sheet.setPrefersGrabberVisible(true)
            rootVc.presentViewController(
              viewControllerToPresent = nav,
              animated = true,
              completion = {

              });
          }
        }
      }
    }
  }
}